@@ -3,7 +3,7 @@ use strict;
 use warnings;
 package Dist::Zilla::PluginBundle::TestingMania;
 BEGIN {
-  $Dist::Zilla::PluginBundle::TestingMania::VERSION = '0.002';
+  $Dist::Zilla::PluginBundle::TestingMania::VERSION = '0.003';
 }
 # ABSTRACT: test your dist with every testing plugin conceivable
 
@@ -15,7 +15,6 @@ sub configure {
     my $self = shift;
 
     my %plugins = (
-        ApacheTest              => 0, # Uncommonly needed
         CheckChangesTests       => 0, # Finnicky and annoying
         CompileTests            => 1,
         ConsistentVersionTest   => 0, # Finnicky and annoying
@@ -28,7 +27,7 @@ sub configure {
         MinimumVersionTests     => 1,
         NoTabsTests             => 1,
         PodCoverageTests        => 1,
-        PodSpellingTests        => 0, # Automated spelling tests are nerve-wracking
+        PodLinkTests            => 1,
         PodSyntaxTests          => 1,
         PortabilityTests        => 1,
         ProgCriticTests         => 0, # Quite personal
@@ -73,7 +72,7 @@ Dist::Zilla::PluginBundle::TestingMania - test your dist with every testing plug
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 DESCRIPTION
 
@@ -95,15 +94,9 @@ are actually I<used> by default.
 
 =item *
 
-L<Dist::Zilla::Plugin::ApacheTest>, which builds a Makefile.PL that uses
-L<ExtUtils::MakeMaker> with L<Apache::Test>. This is not enabled by default;
-see L</"Adding tests">.
-
-=item *
-
 L<Dist::Zilla::Plugin::CheckChangesTests>, which checks your F<Changes> file
 for correctness. See L<Test::CheckChanges> for what that means. This is not
-enabled by default; see L</"Adding tests">.
+enabled by default; see L</"Adding Tests">.
 
 =item *
 
@@ -114,7 +107,7 @@ dist.
 
 L<Dist::Zilla::Plugin::ConsistentVersionTest>, which tests that all modules in
 the dist have the same version. See L<Test::ConsistentVersion> for details. This
-is not enabled by default; see L</"Adding tests">.
+is not enabled by default; see L</"Adding Tests">.
 
 =item *
 
@@ -166,8 +159,10 @@ for what that means.
 
 =item *
 
-L<Dist::Zilla::Plugin::PodSpellingTests>, which checks your L<Pod|perlpod> for
-correct spelling. This is not enabled by default; see L</"Adding tests">.
+L<Dist::Zilla::Plugin::PodLinkTests>, which tests links in your Pod for invalid
+links, or links which return a 404 (Not Found) error when you release your
+dist. Note that smokers won't check for 404s to save hammering the network.
+See L<Test::Pod::LinkCheck> and L<Test::Pod::No404s> for details.
 
 =item *
 
@@ -184,7 +179,7 @@ that means.
 
 L<Dist::Zilla::Plugin::ProgCriticTests>, which helps developers by gradually
 enforcing coding standards. See L<Test::Perl::Critic::Progressive> for what
-that means. This is not enabled by default; see L</"Adding tests">.
+that means. This is not enabled by default; see L</"Adding Tests">.
 
 =item *
 
@@ -198,14 +193,14 @@ variables. See L<Test::Vars> for details.
 
 =back
 
-=head2 Excluding rests
+=head2 Excluding Tests
 
 To exclude a testing plugin, give a comma-separated list in F<dist.ini>:
 
     [@TestingMania]
     skip = EOLTests,NoTabsTests
 
-=head2 Adding tests
+=head2 Adding Tests
 
 To add a testing plugin which is listed above, but not enabled by default,
 give a comma-separated list in F<dist.ini>:
@@ -223,7 +218,7 @@ The latest version of this module is available from the Comprehensive Perl
 Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see L<http://search.cpan.org/dist/Dist-Zilla-PluginBundle-TestingMania/>.
 
-The development version lives at L<http://github.com/doherty/Dist-Zilla-PluginBundle-TestingMania.git>
+The development version lives at L<http://github.com/doherty/Dist-Zilla-PluginBundle-TestingMania>
 and may be cloned from L<git://github.com/doherty/Dist-Zilla-PluginBundle-TestingMania.git>.
 Instead of sending patches, please fork this project using the standard
 git and github infrastructure.
